@@ -9,14 +9,19 @@ def main():
                         help='github organization owning the repo (e.g. NASA-PDS)')
     parser.add_argument('--repository', dest='repository',
                         help='github repository name')
+    parser.add_argument('--dev', dest='dev',
+                        nargs = '?',
+                        const = True, default = False,
+                        help = "Generate requirements with impacts related to latest dev/snapshot version")
     parser.add_argument('--output', dest='output',
-                        help='markdown output file name')
+                        help='directory where version/REQUIREMENTS.md file is created')
     parser.add_argument('--token', dest='token',
                         help='github personal access token')
     args = parser.parse_args()
 
-    requirements = Requirements(args.organization, args.repository, token=args.token)
-    requirements.write_requirements(args.output)
+    requirements = Requirements(args.organization, args.repository, token=args.token, dev=args.dev)
+    requirement_file = requirements.write_requirements(root_dir=args.output)
+    print(requirement_file)
 
 
 if __name__ == "__main__":
